@@ -1,6 +1,10 @@
 mstep2 <-
 function(Y, Tau, Pi, mu, W, Sig, g, p, q)
 {
+  N<-nrow(Y)
+  Vp<-0.1
+  C2p<-0.1
+    
   sig<-rep(NA,g)
   for(i in 1:g)
   {
@@ -11,7 +15,9 @@ function(Y, Tau, Pi, mu, W, Sig, g, p, q)
      W[,,i]<-SW%*%solve((Sig)*diag(q) + ((M_1%*%t(W[,,i]))%*%SW))                                            
      sig[i]<-Pi[i]*(sum(diag(((t(yc*Tau[,i])%*%yc)/sum(Tau[,i])) - (SW%*%(M_1%*%t(W[,,i]))))))               
   } 
-  Sig<-(1/p)*sum(sig)
+  MLESig<-(1/p)*sum(sig)
+  
+  Sig<- ((MLESig*p) + C2p)*(N/(Vp + 2 + (N*p)))
   return(list(W, Sig))
 }# End mstep2
 
